﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Net;
using System.Windows;
using System.Windows.Controls;
using System.Windows.Documents;
using System.Windows.Input;
using System.Windows.Media;
using System.Windows.Media.Animation;
using System.Windows.Shapes;
using System.Xml.Linq;


namespace BookFinder
{
    public class PhotoList
    {
        public string Isbn { get; set; }
        public string Title { get; set; }
        public string Image { get; set; }
        public string Rank { get; set; }
    }



    public partial class Page : UserControl
    {        
        
        const string c_AmazonURL = "http://webservices.amazon.com/onca/xml?Service=AWSECommerceService"
                    + "&Keywords={0}"
                    + "&AWSAccessKeyId={1}"
                    + "&Operation=ItemSearch"
                    + "&SearchIndex=Books"
                    + "&ResponseGroup=Large";

        XNamespace ns = "http://webservices.amazon.com/AWSECommerceService/2005-10-05";
        
        private List<PhotoList> myPhotos = null;

        public Page()
        {
            InitializeComponent();
            myButton.Click += new RoutedEventHandler(GetBooks);
        }

        void GetBooks(object sender, RoutedEventArgs e)
        {
            string requestURL = string.Format(c_AmazonURL, myTextBox.Text, "[Get your access code at aws.amazon.com]");
            WebClient myClient = new WebClient();

            myClient.DownloadStringCompleted += new DownloadStringCompletedEventHandler(ParseImages);
            myClient.DownloadStringAsync(new Uri(requestURL));

        }

        void ParseImages(object sender, DownloadStringCompletedEventArgs e)
        {
            try
            {
                if (e.Error == null)
                {
                    XElement myXML = XElement.Parse(e.Result);

                    var books = from root in myXML.Descendants(ns + "Item")
                                let attr = root.Element(ns + "ItemAttributes")
                                select new PhotoList
                                {
                                    Isbn = (string) attr.Element(ns + "ISBN"),
                                    Title = (string) attr.Element(ns + "Title"),
                                    Rank = (string) root.Element(ns + "SalesRank"),
                                    Image = (string) root.Element(ns + "MediumImage").Element(ns + "URL")
                                };

                    myListBox.ItemsSource = books;
                }
            }
            catch (Exception ex)
            {
                Console.WriteLine("ERROR: " + ex.Message);
            }
        }


    }
}
